<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes"/>

	<xsl:param name="template_file"/>
	<xsl:param name="title" select="page/@title"/>
	<xsl:param name="headerContent" select="page/head/child::*"/>
	
	<!-- These parameters are required for the imported stylesheets -->
	<xsl:param name="generatedDate" select="n"/>
	<xsl:param name="nav_data"/>
	<xsl:param name="nav_style"/>
	<xsl:param name="page_id" select="page/@id"/>
	<xsl:variable name="key_root" select="/page/content"/>
	
	<includes/>
   	
   	<!-- Create content key -->
   	<xsl:key name="content" match="page/content" use="@id"/>

	<!-- Content / layout stuff -->
	<xsl:template match="page">
		<xsl:apply-templates select="document($template_file)"/>
	</xsl:template>
	
	<xsl:template match="contentHolder">
		<xsl:variable name="contentId" select="@contentId"/>
		<xsl:for-each select="$key_root[@id=$contentId]">
			<xsl:choose>
				<xsl:when test="key('content', string($contentId))/child::*">
					<xsl:apply-templates select="key('content', string($contentId))/*"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="key('content', string($contentId))/node()"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="headerContent">
		<xsl:for-each select="$headerContent">
			<xsl:copy-of select="."/>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="html">
		<xsl:text disable-output-escaping="yes">
			<![CDATA[<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">]]>
		</xsl:text>
		<xsl:copy>
			<xsl:apply-templates />
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="title">
		<title><xsl:value-of select="."/><xsl:value-of select="$title"/></title>
	</xsl:template>

	<!-- Copy non-custom nodes -->
	<xsl:template match="*">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>
</xsl:stylesheet>